@@ -2,6 +2,8 @@
 # coding: utf-8
 
 # Python 2.7 Standard Library
+import ConfigParser
+import os
 import xmlrpclib
 
 # Third-Party Libairies
@@ -15,19 +17,30 @@ class Release(setuptools.Command):
 
     user_options = [
       ("list", "l", "list package version info"),
+      ("pypi", "p", "register/upload on pypi"),
+      ("github", "g", "sync git repo with github"),
     ]
 
     def initialize_options(self):
         self.list = None
+        self.pypi = False
+        self.github = False
 
     def finalize_options(self):
-        pass
+        # values extracted from the setup.cfg will be strings
+        if isinstance(self.pypi, str):
+            self.pypi = eval(self.pypi)
+        if isinstance(self.github, str):
+            self.github = eval(self.github)
 
     def run(self):
         if self.list:
             self.display_package_info()
         else:
-            self.release_on_pypi()
+            if self.pypi:
+                self.release_on_pypi()
+            if self.github:
+                pass # do stuff.
 
     def display_package_info(self):
         self.name = self.distribution.get_name()
@@ -60,4 +73,7 @@ class Release(setuptools.Command):
             if not "(200)" in last_line:
                 raise RuntimeError(last_line)
 
+    def release_on_github(self):
+        pass
+
 
